@@ -10,7 +10,8 @@ class DeleteDataConfig(SQLModel):
 
 class DeleteDataCommand(ClientCommand):
 
-    description = """To delete a data association, note this doesn't delete the data, but only the reference."""
+    description = """Delete a data association. Note that this will not delete the data itself,
+                     it will only make it unavailable to experiments and sweeps."""
 
     def run(self) -> None:
         parser = ArgumentParser()
