@@ -5,7 +5,7 @@ from rich.table import Table
 
 class ShowDataCommand(ClientCommand):
 
-    description = "To list all data associations."
+    description = "List all data associations."
 
     def run(self) -> None:
         response = self.invoke_handler()
