@@ -77,7 +77,6 @@ class SweepConfig(SQLModel, table=True):
     direction: str
     stage: str = Stage.NOT_STARTED
     desired_stage: str = Stage.RUNNING
-    shm_size: int = 1024
     disk_size: int = 80
     pip_install_source: bool = False
     data: Dict[str, Optional[str]] = Field(..., sa_column=Column(pydantic_column_type(Dict[str, Optional[str]])))
@@ -312,10 +311,11 @@ def parse_hydra(script_args, args):
 
 class RunSweepCommand(ClientCommand):
 
-    description = """
-        To run a sweep, provide a script, the cloud compute to use, and an optional data.
-        Hyperparameters can be provided as lists or using distributions. Hydra multirun syntax is also supported.
-    """
+    description = """Run a sweep by providing a script, the cloud compute type and optional
+                     data entries to be made available at a given path. Hyperparameters can be
+                     provided as lists (`model.lr=\"[0.01, 0.1]\"`) or using distributions
+                     (`model.lr=\"uniform(0.01, 0.1)\"`, `model.lr=\"log_uniform(0.01, 0.1)\"`).
+                     Hydra multirun override syntax is also supported."""
     requirements = ["traitlets", "lightning_training_studio"]
     SUPPORTED_DISTRIBUTIONS = ("uniform", "log_uniform", "categorical")
 
@@ -334,15 +334,15 @@ class RunSweepCommand(ClientCommand):
         parser.add_argument("--parallel_experiments", default=None, type=int, help="Number of experiments to run.")
         parser.add_argument(
             "--requirements",
-            default="",
+            nargs="+",
+            default=[],
             help="List of requirements separated by a comma or requirements.txt filepath.",
-            type=lambda arg: [el for el in arg.split(",")],
         )
         parser.add_argument(
             "--packages",
-            default="",
+            nargs="+",
+            default=[],
             help="List of system packages to be installed via apt install, separated by a comma.",
-            type=lambda arg: [el for el in arg.split(",")],
         )
         parser.add_argument(
             "--cloud_compute",
@@ -379,12 +379,6 @@ class RunSweepCommand(ClientCommand):
             type=int,
             help="The number of nodes.",
         )
-        parser.add_argument(
-            "--shm_size",
-            default=1024,
-            type=int,
-            help="Size of shared memory in MiB, backed by RAM.",
-        )
         parser.add_argument(
             "--disk_size",
             default=10,
@@ -447,11 +441,7 @@ class RunSweepCommand(ClientCommand):
         if not os.path.exists(hparams.script_path):
             raise FileNotFoundError(f"The provided script doesn't exist: {hparams.script_path}")
 
-        if (
-            len(hparams.requirements) == 1
-            and hparams.requirements[0]  # noqa: W503
-            and Path(hparams.requirements[0]).resolve().exists()  # noqa: W503
-        ):
+        if len(hparams.requirements) == 1 and Path(hparams.requirements[0]).resolve().exists():
             requirements_path = Path(hparams.requirements[0]).resolve()
             with open(requirements_path, "r") as f:
                 hparams.requirements = [line.replace("\n", "") for line in f.readlines() if line.strip()]
@@ -479,7 +469,6 @@ class RunSweepCommand(ClientCommand):
             logger=hparams.logger,
             direction=hparams.direction,
             experiments={},
-            shm_size=hparams.shm_size,
             disk_size=hparams.disk_size,
             pip_install_source=hparams.pip_install_source,
             data=data,
